PBExpression_Payload enum

Inheritance
Available extensions

Values

rawString → const PBExpression_Payload
scaffold → const PBExpression_Payload
center → const PBExpression_Payload
text → const PBExpression_Payload
appBar → const PBExpression_Payload
column → const PBExpression_Payload
elevatedButton → const PBExpression_Payload
notSet → const PBExpression_Payload

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PBExpression_Payload>
A constant List of the values in this enum, in order of their declaration.