PDUI Flutter
This is the mobile side library of the best SDUI Library!
PDUI Github
To install this library on your Flutter app add this to you pubspec.yaml:
dependencies:
pdui_flutter: 0.0.1
Then run flutter pub get to download the library
Getting started
You just need to use the PduiScreen widget wherever you want on your application.
If you want to use PDUINavigation you need to set the navigatorKey as indicated below.
If you want PDUI controlling youe whole app your main.dart will look like this:
import 'package:flutter/material.dart';
import 'package:pdui_flutter/core/pdui_context.dart';
import 'package:pdui_flutter/screens/pdui_home.dart';
void main() {
runApp(const MyApp());
}
class MyApp extends StatelessWidget {
const MyApp({super.key});
@override
Widget build(BuildContext context) {
return MaterialApp(
title: 'PDUI Flutter Demo',
theme: ThemeData(
colorScheme: ColorScheme.fromSeed(seedColor: Colors.deepPurple),
),
navigatorKey: PduiContext.navigatorKey, //Very important, without this your navigation won't work!!!
home: PduiScreen(
expressionId: "home", //Don't forget to register this route on your server
useCache: false, // true if you want to use it, remember to have a redis cache running on the default port
),
);
}
}
You should be good to go, now build the most incredible screen on your server!!!
Libraries
- core/pdui_context
- core/pdui_debug_print
- core/pdui_expression
- core/pdui_expression_parser
- core/pdui_generic_fn
- http_client/pdui_http_client
- models/pdui_expression
- models/pdui_fn
- pdui_flutter
- proto_out/pdui-proto-out.pb
- proto_out/pdui-proto-out.pbenum
- proto_out/pdui-proto-out.pbjson
- screens/pdui_loading_screen
- screens/pdui_screen
- widgets/pdui_app_bar
- widgets/pdui_center
- widgets/pdui_column
- widgets/pdui_scaffold
- widgets/pdui_text
- widgets/pdui_widget